@@ -1,10 +1,10 @@
 """Jetpack is a set of useful utility functions for scientific python."""
 
 from . import colors as c
-from .style import *
 from .chart_utils import *
-from .plots import *
 from .images import *
+from .plots import *
+from .style import *
 
 from .signals import *
 from .timepiece import *
@@ -14,6 +14,6 @@ from .version import __version__
 light_mode()
 
 try:
-    set_font('Helvetica')
+    set_font("Helvetica")
 except ValueError:
     pass
